library(rWSBIM1322)
library(tidyverse)

## Visualisation - suite

data("hiiragi2013df1")
View(hiiragi2013df1)

ggplot(hiiragi2013df1, 
       aes(x = X1426642_at,
           y = X1418765_at)) + 
  geom_point(aes(colour = sampleGroup)) + 
  geom_smooth(method = "loess")


## 1D 

selected_genes <- c(Fgf4 = "X1420085_at",
                    Gata4 = "X1418863_at",
                    Gata6 = "X1425463_at",
                    Sox2 = "X1416967_at")
selected_genes
dfx <- hiiragi2013df1[, selected_genes]
dim(dfx)

View(dfx)
colnames(dfx)
colnames(dfx) <- names(selected_genes)

genes <- 
  dfx %>% 
  pivot_longer(names_to = "gene",
               values_to = "expression",
               everything())
View(genes)

genes %>% 
  filter(gene == "Gata4") %>% 
  ggplot(aes(x = expression)) + 
  geom_histogram()

genes %>% 
  filter(gene == "Gata4") %>% 
  ggplot(aes(y = expression)) + 
  geom_boxplot()

genes %>% 
  ggplot(aes(x = gene,
             y = expression,
             fill = gene)) + 
  geom_boxplot()

## violin
genes %>% 
  ggplot(aes(x = gene,
             y = expression,
             fill = gene)) + 
  geom_violin()



p <- genes %>% 
  ggplot(aes(x = gene,
             y = expression,
             fill = gene))


p + geom_jitter(aes(colour = gene))

p + geom_dotplot(binaxis = "y",
                 stackdir = "center",
                 stackratio = 0.75)

install.packages("ggbeeswarm")
library(ggbeeswarm)

p + geom_beeswarm(aes(colour = gene))

genes %>% 
  filter(gene == "Gata4") %>% 
  ggplot(aes(x = expression)) + 
  geom_histogram()

genes %>% 
  filter(gene == "Gata4") %>% 
  ggplot(aes(x = expression)) + 
  geom_density()

genes %>% 
  ggplot(aes(x = expression)) + 
  geom_density(aes(colour = gene))

genes %>% 
  ggplot(aes(x = expression)) + 
  stat_ecdf(aes(colour = gene))

## 2D

data("hiiragi2013df2")
View(hiiragi2013df2)

scp <- 
  ggplot(hiiragi2013df2, 
       aes(x = `59 E4.5 (PE)`,
           y = `92 E4.5 (FGF4-KO)`))
scp

scp + geom_point()

## opacity (alpha)
scp + geom_point(alpha = 0.1)

scp + geom_density2d(h = 0.5, bins = 60)

scp + geom_hex()

ggplot(hiiragi2013df1, 
       aes(x = X1426642_at,
           y = X1418765_at, 
           colour = sampleGroup)) + 
  geom_point()

ggplot(hiiragi2013df1, 
       aes(x = X1426642_at,
           y = X1418765_at, 
           colour = sampleGroup)) + 
  geom_point() + 
  facet_grid(. ~ sampleGroup)

ggplot(hiiragi2013df1, 
       aes(x = X1426642_at,
           y = X1418765_at, 
           colour = sampleGroup)) + 
  geom_point() + 
  facet_grid(Embryonic.day ~ lineage)


library(plotly)

p <- ggplot(hiiragi2013df1, 
       aes(x = X1426642_at,
           y = X1418765_at, 
           colour = sampleGroup)) + 
  geom_point()

ggplotly(p)

